%define anolis_release 2
%bcond_with check

Summary: Tracks and displays system calls associated with a running process
Name: strace
Version: 6.12
Release: %{anolis_release}%{?dist}
# The test suite is GPLv2+, all the rest is LGPLv2.1+.
License: LGPL-2.1+ and GPL-2.0+
URL: https://strace.io
Source: https://strace.io/files/%{version}/strace-%{version}.tar.xz
Patch0: strace-6.6-sw.patch

BuildRequires: xz
BuildRequires: gcc gzip make

# Install Bluetooth headers for AF_BLUETOOTH sockets decoding.
BuildRequires: pkgconfig(bluez)

# Install elfutils-devel or libdw-devel to enable strace -k option.
# Install binutils-devel to enable symbol demangling.
BuildRequires: elfutils-devel binutils-devel
BuildRequires: libselinux-devel

# Fallback definitions for make_build/make_install macros
%{?!__make:       %global __make %_bindir/make}
%{?!__install:    %global __install %_bindir/install}
%{?!make_build:   %global make_build %__make %{?_smp_mflags}}
%{?!make_install: %global make_install %__make install DESTDIR="%{?buildroot}" INSTALL="%__install -p"}

%description
The strace program intercepts and records the system calls called and
received by a running process.  Strace can print a record of each
system call, its arguments and its return value.  Strace is useful for
diagnosing problems and debugging, as well as for instructional
purposes.

Install strace if you need a tool to track the system calls made and
received by a process.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
echo -n %version-%release > .tarball-version
echo -n 2023 > .year
echo -n 2022-10-16 > doc/.strace.1.in.date
echo -n 2022-01-01 > doc/.strace-log-merge.1.in.date

%build
echo 'BEGIN OF BUILD ENVIRONMENT INFORMATION'
uname -a |head -1
libc="$(ldd /bin/sh |sed -n 's|^[^/]*\(/[^ ]*/libc\.so[^ ]*\).*|\1|p' |head -1)"
$libc |head -1
file -L /bin/sh
gcc --version |head -1
ld --version |head -1
kver="$(printf '%%s\n%%s\n' '#include <linux/version.h>' 'LINUX_VERSION_CODE' | gcc -E -P -)"
printf 'kernel-headers %%s.%%s.%%s\n' $(($kver/65536)) $(($kver/256%%256)) $(($kver%%256))
echo 'END OF BUILD ENVIRONMENT INFORMATION'

CFLAGS_FOR_BUILD="$RPM_OPT_FLAGS"; export CFLAGS_FOR_BUILD
%configure --enable-mpers=check
%make_build

%install
%make_install

# some say uncompressed changelog files are too big
for f in ChangeLog ChangeLog-CVS; do
	gzip -9n < "$f" > "$f".gz &
done
wait

%generate_compatibility_deps

%if %{with check}
%check
%{buildroot}%{_bindir}/strace -V
%make_build -k check VERBOSE=1
echo 'BEGIN OF TEST SUITE INFORMATION'
tail -n 99999 -- tests*/test-suite.log tests*/ksysent.gen.log
find tests* -type f -name '*.log' -print0 |
	xargs -r0 grep -H '^KERNEL BUG:' -- ||:
echo 'END OF TEST SUITE INFORMATION'
%endif

%files
%dir %{abidir}
%license COPYING
%{_bindir}/strace
%{abidir}/strace-option.list
%{_bindir}/strace-log-merge
%{abidir}/strace-log-merge-option.list
%{_mandir}/man1/*

%files doc
%doc CREDITS ChangeLog.gz ChangeLog-CVS.gz NEWS README

%changelog
* Tue Mar 25 2025 pangqing <pangqing@uniontech.com> - 6.12-2
- Add third arch support

* Tue Feb 18 2025 Chang Gao <taifu-gc@linux.alibaba.com> - 6.12-1
- Update to 6.12
- Remove loongarch patch because we do not need it now

* Mon Apr 1 2024 Pengda Dou <doupengda@loongson.cn> - 5.12-2
- add support for loongarch64

* Wed Mar 29 2023 happy_orange <songnannan@linux.alibaba.com> - 5.12-1
- rollback to version 5.12 to make the build success

* Sat Mar 04 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 6.2-1
- update to 6.2

* Mon Mar 07 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 5.16-1
- Init from upstream v5.16
